@@ -5,20 +5,35 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
+#include <QAudioFormat>
+#include <QAudioInput>
+#include <QMediaCaptureSession>
+
 #include "audioprober.h"
 
 AudioProber::AudioProber(QObject *parent)
-    : QAudioProbe{ parent }
+    : QAudioDecoder{ parent }
 {}
 
-AudioProber::AudioProber(QObject *parent, QAudioRecorder *source) 
-    : QAudioProbe{ parent }
+AudioProber::AudioProber(QObject *parent, QMediaRecorder *source)
+    : QAudioDecoder{ parent }
     , m_recorderSource{ source }
 {
-    connect(this, &AudioProber::audioBufferProbed, this, &AudioProber::process);
-    
+    QAudioFormat format;
+    // Set up the desired format, for example:
+    format.setSampleRate(8000);
+    format.setChannelCount(1);
+    format.setSampleFormat(QAudioFormat::UInt8);
+
+    QAudioDevice device = source->captureSession()->audioInput()->device();
+    if (!device.isFormatSupported(format)) {
+        qWarning() << "Default format not supported, trying to use the nearest.";
+    }
+
+    m_audioSource = new QAudioSource(device, format, this);
+
     // connect to recorder
-    connect(m_recorderSource, &QAudioRecorder::stateChanged, this, &AudioProber::handleRecorderState);
+    connect(m_recorderSource, &QMediaRecorder::recorderStateChanged, this, &AudioProber::handleRecorderState);
     
     // loop to add volume bars 
     volumeBarTimer = new QTimer(this);
@@ -27,13 +42,13 @@ AudioProber::AudioProber(QObject *parent, QAudioRecorder *source)
 }
 
 AudioProber::AudioProber(QObject *parent, QMediaPlayer *source) 
-    : QAudioProbe{ parent }
+    : QAudioDecoder{ parent }
     , m_playerSource{ source }
 {
-    connect(this, &AudioProber::audioBufferProbed, this, &AudioProber::process);
+    connect(this, &AudioProber::bufferReady, this, &AudioProber::process);
     
     // connect to player
-    connect(m_playerSource, &QMediaPlayer::stateChanged, this, &AudioProber::handlePlayerState);
+    connect(m_playerSource, &QMediaPlayer::playbackStateChanged, this, &AudioProber::handlePlayerState);
     
     // loop to add volume bars 
     volumeBarTimer = new QTimer(this);
@@ -41,19 +56,22 @@ AudioProber::AudioProber(QObject *parent, QMediaPlayer *source)
     volumeBarTimer->setInterval(150);
 }
 
-void AudioProber::handleRecorderState(QAudioRecorder::State state) {
-    if (state == QAudioRecorder::RecordingState) {
+void AudioProber::handleRecorderState(QMediaRecorder::RecorderState state) {
+    if (state == QMediaRecorder::RecordingState) {
+        start();
         volumeBarTimer->start();
-    } else if (state == QAudioRecorder::PausedState) {
+    } else if (state == QMediaRecorder::PausedState) {
+        stop();
         volumeBarTimer->stop();
-    } else if (state == QAudioRecorder::StoppedState) {
+    } else if (state == QMediaRecorder::StoppedState) {
+        stop();
         volumeBarTimer->stop();
         // clear volumes list
         clearVolumesList();
     }
 }
 
-void AudioProber::handlePlayerState(QMediaPlayer::State state) {
+void AudioProber::handlePlayerState(QMediaPlayer::PlaybackState state) {
     if (state == QMediaPlayer::PlayingState) {
         volumeBarTimer->start();
     } else if (state == QMediaPlayer::PausedState) {
@@ -65,9 +83,20 @@ void AudioProber::handlePlayerState(QMediaPlayer::State state) {
     }
 }
 
+void AudioProber::start()
+{
+    qDebug() << "pang";
+    QIODevice *iodevice = m_audioSource->start();
+    qDebug() << iodevice;
+    setSourceDevice(iodevice);
+    qDebug() << sourceDevice();
+    QAudioDecoder::start();
+    connect(this, &QAudioDecoder::bufferReady, this, &AudioProber::process);
+}
+
 void AudioProber::processVolumeBar() 
 {
-    if (isActive()) {
+    if (isDecoding()) {
         // m_audioLen might be 0
         const int val = m_audioLen == 0 ? 0 : m_audioSum / m_audioLen;
 
@@ -91,14 +120,17 @@ void AudioProber::processVolumeBar()
     }
 }
 
-void AudioProber::process(QAudioBuffer buffer) 
+void AudioProber::process()
 {
+    qDebug() << "ping";
     int sum = 0;
+    auto buffer = read();
     for (int i = 0; i < buffer.sampleCount(); i++) {
-        sum += abs(static_cast<short *>(buffer.data())[i]);
+        const short *bufferData = buffer.data<short>();
+        sum += abs(bufferData[i]);
     }
 
-    sum /= buffer.sampleCount();
+    sum /= read().sampleCount();
     
     m_audioSum += sum;
     m_audioLen++;
